# RapidPE

The original low-latency gravitational wave parameter estimation code.

# Installation

The typical way to run RapidPE is as part of the [RapidPE--RIFT Pipeline](https://git.ligo.org/rapidpe-rift/rapidpe-rift-pipe).  If you do want to install RapidPE directly, you can install it in one of three ways
```bash
# Install from Conda (recommended)
conda install rapid-pe
```

```bash
# Install from PyPI
pip install rapid-pe
```

```bash
# Install from source
git clone https://git.ligo.org/rapidpe-rift/rapidpe
cd rapidpe
pip install .
```

# Credit

Copyright (c) 2012-2023 [RapidPE Contributors](CONTRIBUTORS.md)
